@@ -7,6 +7,7 @@ This command runs a bunch of pip/conda commands (depending on what's available)
 and it does the *right thing*: creating a new environment if needed, and
 locking dependencies.
 """
+import os
 import json
 import uuid
 import warnings
@@ -34,6 +35,9 @@ def get_key():
     This gets the user cloud api key, returns None if doesn't exist.
     config.yaml is the default user conf file to fetch from.
     """
+    if 'PLOOMBER_CLOUD_KEY' in os.environ:
+        return os.environ['PLOOMBER_CLOUD_KEY']
+
     return UserSettings().cloud_key
 
 
