@@ -12,7 +12,12 @@ import jupytext
 import nbformat
 import nbconvert
 from nbconvert import ExporterNameError
-from nbconvert.exporters.webpdf import WebPDFExporter
+
+# this was introduced in nbconvert 6.0
+try:
+    from nbconvert.exporters.webpdf import WebPDFExporter
+except ModuleNotFoundError:
+    WebPDFExporter = None
 
 # papermill is importing a deprecated module from pyarrow
 with warnings.catch_warnings():
@@ -86,7 +91,7 @@ def _check_exporter(exporter, path_to_output):
     """
     Validate if the user can use the selected exporter
     """
-    if exporter is WebPDFExporter:
+    if WebPDFExporter is not None and exporter is WebPDFExporter:
         pyppeteer_installed = find_spec('pyppeteer') is not None
 
         if not pyppeteer_installed:
@@ -490,16 +495,16 @@ class NotebookRunner(NotebookMixin, Task):
     >>> # do not include input code (only cell's output)
     >>> NotebookRunner(Path('nb.ipynb'), File('out-1.html'), dag=dag,
     ...                nbconvert_export_kwargs={'exclude_input': True},
-    ...                name=1)
+    ...                name=1) # doctest: +SKIP
     >>> # Selectively remove cells with the tag "remove"
     >>> config = {'TagRemovePreprocessor': {'remove_cell_tags': ('remove',)},
-    ...           'HTMLExporter':
-    ...             {'preprocessors':
-    ...             ['nbconvert.preprocessors.TagRemovePreprocessor']}}
+    ...        'HTMLExporter':
+    ...         {'preprocessors':
+    ...    ['nbconvert.preprocessors.TagRemovePreprocessor']}} # doctest: +SKIP
     >>> NotebookRunner(Path('nb.ipynb'), File('out-2.html'), dag=dag,
     ...                nbconvert_export_kwargs={'config': config},
-    ...                name=2)
-    >>> dag.build()
+    ...                name=2) # doctest: +SKIP
+    >>> dag.build() # doctest: +SKIP
 
     Notes
     -----
