@@ -28,6 +28,7 @@ The data we collect is limited to:
     telemetry_version - Telemetry version
 
 """
+import logging
 import datetime
 import http.client as httplib
 import json
@@ -52,6 +53,9 @@ DEFAULT_PLOOMBER_CONF = 'uid.yaml'
 CONF_DIR = "stats"
 posthog.project_api_key = 'phc_P9SpSeypyPwxrMdFn2edOOEooQioF2axppyEeDwtMSP'
 PLOOMBER_HOME_DIR = os.getenv("PLOOMBER_HOME_DIR")
+# posthog client logs errors which are confusing for users
+# https://github.com/PostHog/posthog-python/blob/fd92502d990499a61804034e3feb7e17f64a14a1/posthog/consumer.py#L81
+logging.getLogger("posthog").disabled = True
 
 
 class UserSettings(Config):
@@ -295,10 +299,10 @@ def get_latest_version():
 
 def is_cloud_user():
     """
-        The function checks if the cloud api key is set for the user.
-        Checks if the cloud_key is set in the User conf file (config.yaml).
-        returns True/False accordingly.
-        """
+    The function checks if the cloud api key is set for the user.
+    Checks if the cloud_key is set in the User conf file (config.yaml).
+    returns True/False accordingly.
+    """
     settings = UserSettings()
     return settings.cloud_key
 
