@@ -11,9 +11,15 @@ class Interval:
     >>> from ploomber.util import Interval
     >>> from datetime import date
     >>> from dateutil.relativedelta import relativedelta
-    >>> Interval(date(year=2010, month=1, day=1),
-    ...          date(year=2019, month=6, day=1),
-    ...          relativedelta(years=1)).expand()
+    >>> interval = Interval(date(year=2020, month=1, day=1),
+    ...                     date(year=2022, month=6, day=1),
+    ...                     relativedelta(years=1)).expand()
+    >>> interval[0]
+    (datetime.date(2020, 1, 1), datetime.date(2021, 1, 1))
+    >>> interval[1]
+    (datetime.date(2021, 1, 1), datetime.date(2022, 1, 1))
+    >>> interval[2]
+    (datetime.date(2022, 1, 1), datetime.date(2022, 6, 1))
     """
     def __init__(self, lower, upper, delta):
         if lower >= upper:
@@ -61,10 +67,17 @@ class ParamGrid:
     --------
     >>> pg = ParamGrid({'a': [1, 2, 3], 'b': [2, 4, 6]})
     >>> list(pg.zip())
-    >>> list(pg.product())
+    [{'a': 1, 'b': 2}, {'a': 2, 'b': 4}, {'a': 3, 'b': 6}]
+
+    >>> list(pg.product())  # doctest: +NORMALIZE_WHITESPACE
+    [{'a': 1, 'b': 2}, {'a': 1, 'b': 4}, {'a': 1, 'b': 6}, {'a': 2, 'b': 2},
+    {'a': 2, 'b': 4}, {'a': 2, 'b': 6}, {'a': 3, 'b': 2}, {'a': 3, 'b': 4},
+    {'a': 3, 'b': 6}]
 
     >>> pg = ParamGrid({'a': Interval(0, 10, 2), 'b': [2, 4, 6, 8, 10]})
-    >>> list(pg.zip())
+    >>> list(pg.zip())  # doctest: +NORMALIZE_WHITESPACE
+    [{'a': (0, 2), 'b': 2}, {'a': (2, 4), 'b': 4}, {'a': (4, 6), 'b': 6},
+    {'a': (6, 8), 'b': 8}, {'a': (8, 10), 'b': 10}]
 
     Notes
     -----
